package DTDDoc;

import java.io.*;
import java.util.HashSet;

import org.apache.tools.ant.taskdefs.MatchingTask;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.DirectoryScanner;

/** This is the DTDDoc ant task. */

public class DTDDocTask extends MatchingTask {

    private boolean showHiddenTags = false;
	
    public void setShowHiddenTags( boolean f) {
	    showHiddenTags = f;
	}
	
	private boolean showFixmeTags = true;
    public void setShowFixmeTags( boolean f) {
	    showFixmeTags = f;
	}

	private String sourceDir = ".";
    public void setSourceDir( String s) {
	    sourceDir = s;
	}

	private String destDir = "";
    public void setDestDir( String s) {
	    destDir = s;
	}
	
	private String docTitle = "";
    public void setDocTitle( String s) {
	    docTitle = s;
	}	
	
	private File styleSheet = null;
	public void setStyleSheet( String s) {
		styleSheet = new File(s);
		if( !styleSheet.canRead()) {
			styleSheet = null;
			System.out.println("Sorry, the style sheet '"+s+"' was not" +
				" found. I'll use the default one instead.");
		}
	}
	
	public DTDDocTask() {
	}
		
    public void execute() throws BuildException {
	    System.out.println("Welcome to DTDDoc.");
	    System.out.println("Parts of this program are from DTDParser" +
	    	" and RegExp of the Apache Project.");
		System.out.println();
	    System.out.println("The settings are :");
	    
	    System.out.print("   ");
	    if( showHiddenTags) System.out.print("Don't show ");
	    	else System.out.print("Show ");
		System.out.println("@hidden tags.");
		
		System.out.print("   ");
		if( showFixmeTags) System.out.print("Don't show ");
			else System.out.print("Show ");
		System.out.println("@fixme tags.");

		if( styleSheet != null) {
			System.out.print("   Style sheet source is ");
			System.out.println( "'"+styleSheet.getPath()+"'.");
		} else
			System.out.println("   No style sheet was specified.");

		File sDir = new File( sourceDir);
		File dDir = new File( destDir);
		
		try {		
			System.out.println("   Source directory is '" +
				sDir.getCanonicalPath() + "'.");
			System.out.println("   Destination directory is '" +
				dDir.getCanonicalPath() + "'.");
		} catch ( IOException ex) {
			System.out.println("Something went wrong while figuring out" +
				" the source/dest directories paths."+ex);
			return;
		}
		
		System.out.println();
		System.out.println("Commencez !");
		System.out.println();
		
		
		DirectoryScanner scanner = getDirectoryScanner( sDir );
		String[] files = scanner.getIncludedFiles();

		if( files.length == 0)
			System.out.println(" No files to process ! Please note that you" +
				" have to specify which files to include with the <include> tags. There's no" +
				" automatic selection of all DTD's anymore (as of 0.0.7).");
		
		HashSet scan = new HashSet();
        for (int i = 0; i < files.length; i++) {
			scan.add( new File( sDir, files[i]));
		}
		
        DTDCommenter commenter = new DTDCommenter();	
		try {
		    commenter.commentDTDs( scan,
			                       sDir,
								   dDir,
								   showHiddenTags, showFixmeTags, docTitle, styleSheet);
		} catch ( Exception ex) {
		    System.out.println("A problem occured while executing the DTDDoc task !");
		    ex.printStackTrace();
		    
		    return;
		}
	}
}
