package DTDDoc;

import java.text.Collator;

/** <p>This class stores a simple immutable pair (key,value). A pair is
 * comparable on its "key". That is a = b iff a.key = b.key.</p>
 * 
 * <p>Moreover, the comparison
 * operator is a "collator". This was chosen so we can order pairs in 
 * "natural" order.</p>
 * 
 * @author Stefan Champailler
 */

public class ImmutablePair implements Comparable {
		
	/** The collator will be sused to compare two pairs.
	 * @see #compareTo
	 */
	private static Collator collator = Collator.getInstance();
	
	/** The key-part of the pair. */
	private String key;
	
	/** The value-part of the pair. */
	private Object value;

	/** Builds a pair.
	 * 
	 * @param key The key part of the pair.
	 * @param value The value part of the pair.
	 */
	public ImmutablePair( String key, Object value) {
		this.key = key;
		this.value = value;
	}

	/** Compares this key to another. We use a {@link #collator} to do that. */
	public int compareTo( Object immutablePair) {	
		return collator.compare( key, ((ImmutablePair) immutablePair).key);
	}
	
	/** Key accessor.
	 * @return The key part of the pair.
	 */
	
	public Comparable getKey() {
		return key;
	}

	/** Value accessor.
	 * @return The value part of the pair.
	 */
	
	public Object getValue() {
		return value;
	}
}
